# npp_materialslab_tools

This is a package with python tools for the materials lab in HMU

Author: Nikolaos Papadakis

Nikolaos Papadakis 


# installation

cd to the directory and execute

> python setup.py install
> python setup.py develop

or (when loaded to pypi)

> pip install npp_materialslab_tools

to use it import:

> import npp_materialslab_tools as mlt
